Coverage for /home/chris/workspace/django-shop/shop/order_signals: 100.00%

# Coverage for /home/chris/workspace/django-shop/shop/order_signals : 100.00%

## 7 statements 7 run 0 missing 0 excluded 0 partial

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | import django.dispatch # Order-related signals """Emitted when the Cart was converted to an Order""" processing = django.dispatch.Signal(providing_args=['order']) """Emitted when the user is shown the "select a payment method" page """ payment_selection = django.dispatch.Signal(providing_args=['order']) """Emitted when the user finished placing his order (regardless of the payment success or failure)""" confirmed = django.dispatch.Signal(providing_args=['order']) """Emitted when the payment was received for the Order""" completed = django.dispatch.Signal(providing_args=['order']) """Emitted if the payment was refused or other fatal problem""" cancelled = django.dispatch.Signal(providing_args=['order']) """Emitted (manually) when the shop clerk or robot shipped the order""" shipped = django.dispatch.Signal(providing_args=['order'])